==> broadleaf-common-3.1.1-GA-sources.jar: org/broadleafcommerce/common/filter/FilterDefinition.java <==
/*
 * #%L
 * BroadleafCommerce Common Libraries
 * %%
 * Copyright (C) 2009 - 2013 Broadleaf Commerce
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package org.broadleafcommerce.common.filter;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Jeff Fischer
 */
public class FilterDefinition {

    protected String name;
    protected List<FilterParameter> params = new ArrayList<FilterParameter>();
    protected String entityImplementationClassName;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<FilterParameter> getParams() {
        return params;
    }

    public void setParams(List<FilterParameter> params) {
        this.params = params;
    }

    public String getEntityImplementationClassName() {
        return entityImplementationClassName;
    }

    public void setEntityImplementationClassName(String entityImplementationClassName) {
        this.entityImplementationClassName = entityImplementationClassName;
    }
}

==> broadleaf-common-4.0.23-GA-sources.jar: org/broadleafcommerce/common/filter/FilterDefinition.java <==
/*
 * #%L
 * BroadleafCommerce Common Libraries
 * %%
 * Copyright (C) 2009 - 2013 Broadleaf Commerce
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package org.broadleafcommerce.common.filter;

import org.apache.commons.collections.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * Configuration bean that represents a Hibernate FilterDefinition
 *
 * @author Jeff Fischer
 */
public class FilterDefinition {

    protected String name;
    protected List<FilterParameter> params = new ArrayList<FilterParameter>();
    protected String entityImplementationClassName;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<FilterParameter> getParams() {
        return params;
    }

    public void setParams(List<FilterParameter> params) {
        this.params = params;
    }

    public String getEntityImplementationClassName() {
        return entityImplementationClassName;
    }

    public void setEntityImplementationClassName(String entityImplementationClassName) {
        this.entityImplementationClassName = entityImplementationClassName;
    }

    public FilterDefinition copy() {
        FilterDefinition copy = new FilterDefinition();
        copy.setName(name);
        if (!CollectionUtils.isEmpty(params)) {
            copy.getParams().addAll(params);
        }
        copy.setEntityImplementationClassName(entityImplementationClassName);
        return copy;
    }
}
